@@ -3,4 +3,5 @@ import os
 
 def install():
    script.install()
-   print(script.get_path())
\ No newline at end of file
+   path = os.path.abspath(os.getcwd())
+   print(f"install path: {path}")
\ No newline at end of file
